import gql from 'graphql-tag'
import { graphql } from 'react-apollo'
import { compose, withHandlers, withProps } from 'recompose'

const userFragment = gql`
  fragment userDetails on User {
    id
    admin
    email
    title
    country
    username
    lastName
    isActive
    firstName
    affiliation
    isConfirmed
    editorInChief
    handlingEditor
  }
`

const getUsersQuery = gql`
  {
    users {
      ...userDetails
    }
  }
  ${userFragment}
`

const addUserMutation = gql`
  mutation addUser($user: UserInput) {
    createUser(input: $user) {
      ...userDetails
    }
  }
  ${userFragment}
`

const updateUserMutation = gql`
  mutation updateUser($id: ID, $input: UserInput) {
    updateUser(id: $id, input: $input) {
      ...userDetails
    }
  }
  ${userFragment}
`

export default compose(
  graphql(getUsersQuery),
  graphql(addUserMutation, {
    name: 'addUser',
  }),
  graphql(updateUserMutation, {
    name: 'updateUser',
  }),
  withHandlers({
    addUser: ({ addUser }) => (values, props) => {},
    updateUser: ({ updateUser }) => (
      { __typename, id, ...input },
      { props: { hideModal } },
    ) => {
      updateUser({
        variables: {
          id,
          input,
        },
      }).then(hideModal)
    },
  }),
  withProps(({ data }) => ({
    users: data.users,
  })),
)
